---
name: Question
about: Ask a question about how to use halomod
title: "[Question]"
labels: 'Type: question'
assignees: steven-murray

---

<!-- Please ask your question below. Please try to be as specific as you can, and provide information about your installed version of hmf and Python -->
